@@ -215,7 +215,7 @@ sub errorCheck
 ##############################################################################
 sub minimalUsageNotes {
     
-    print "Usage: queryCui.pl [OPTIONS] <semantic type> \n";
+    print "Usage: getStDef.pl [OPTIONS] <semantic type> \n";
     &askHelp();
     exit;
 }
@@ -254,7 +254,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getStDef.pl,v 1.8 2009/02/09 22:49:54 btmcinnes Exp $';
+    print '$Id: getStDef.pl,v 1.9 2009/10/13 18:46:06 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
